==> onos-yang-runtime-2.2.0-sources.jar: org/onosproject/yang/gen/v1/leafreftest/rev20160524/leafreftest/cont1/DefaultAugmentedCont1.java <==
/*
 * Copyright 2017-present Open Networking Foundation
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.onosproject.yang.gen.v1.leafreftest.rev20160524.leafreftest.cont1;

import java.util.BitSet;
import java.util.Objects;
import java.util.StringJoiner;
import org.onosproject.yang.model.InnerModelObject;

/**
 * Represents the implementation of augmentedCont1.
 *
 * <p>
 * valueLeafFlags identify the leafs whose value are explicitly set
 * Applicable in protocol edit and query operation.
 * </p>
 */
public class DefaultAugmentedCont1 extends InnerModelObject implements AugmentedCont1 {
    protected String lastname;
    protected BitSet valueLeafFlags = new BitSet();

    @Override
    public String lastname() {
        return lastname;
    }

    @Override
    public BitSet valueLeafFlags() {
        return valueLeafFlags;
    }

    @Override
    public void lastname(String lastname) {
        valueLeafFlags.set(LeafIdentifier.LASTNAME.getLeafIndex());
        this.lastname = lastname;
    }

    @Override
    public int hashCode() {
        return Objects.hash(lastname, valueLeafFlags);
    }

    @Override
    public boolean equals(Object obj) {
        if (this == obj) {
            return true;
        }
        if (obj instanceof DefaultAugmentedCont1) {
            DefaultAugmentedCont1 other = (DefaultAugmentedCont1) obj;
            return
                Objects.equals(lastname, other.lastname) &&
                Objects.equals(valueLeafFlags, other.valueLeafFlags);
        }
        return false;
    }

    @Override
    public String toString() {
        return new StringJoiner(", ", getClass().getSimpleName() +"{", "}")
            .add("lastname=" + lastname)
            .add("valueLeafFlags=" + valueLeafFlags)
            .toString();
    }


    /**
     * Creates an instance of defaultAugmentedCont1.
     */
    public DefaultAugmentedCont1() {
    }


    @Override
    public boolean isLeafValueSet(LeafIdentifier leaf) {
        return valueLeafFlags.get(leaf.getLeafIndex());
    }

}

==> onos-yang-runtime-2.3.1-sources.jar: org/onosproject/yang/gen/v1/leafreftest/rev20160524/leafreftest/cont1/DefaultAugmentedCont1.java <==
/*
 * Copyright 2017-present Open Networking Foundation
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.onosproject.yang.gen.v1.leafreftest.rev20160524.leafreftest.cont1;

import java.util.BitSet;
import java.util.Objects;
import java.util.StringJoiner;
import org.onosproject.yang.model.InnerModelObject;

/**
 * Represents the implementation of augmentedCont1.
 *
 * <p>
 * valueLeafFlags identify the leafs whose value are explicitly set
 * Applicable in protocol edit and query operation.
 * </p>
 */
public class DefaultAugmentedCont1 extends InnerModelObject implements AugmentedCont1 {
    protected String lastname;
    protected BitSet valueLeafFlags = new BitSet();

    @Override
    public String lastname() {
        return lastname;
    }

    @Override
    public BitSet valueLeafFlags() {
        return valueLeafFlags;
    }

    @Override
    public void lastname(String lastname) {
        valueLeafFlags.set(LeafIdentifier.LASTNAME.getLeafIndex());
        this.lastname = lastname;
    }

    @Override
    public int hashCode() {
        return Objects.hash(lastname, valueLeafFlags);
    }

    @Override
    public boolean equals(Object obj) {
        if (this == obj) {
            return true;
        }
        if (obj instanceof DefaultAugmentedCont1) {
            DefaultAugmentedCont1 other = (DefaultAugmentedCont1) obj;
            return
                Objects.deepEquals(lastname, other.lastname) &&
                Objects.deepEquals(valueLeafFlags, other.valueLeafFlags);
        }
        return false;
    }

    @Override
    public String toString() {
        return new StringJoiner(", ", getClass().getSimpleName() +"{", "}")
            .add("lastname=" + lastname)
            .add("valueLeafFlags=" + valueLeafFlags)
            .toString();
    }


    /**
     * Creates an instance of defaultAugmentedCont1.
     */
    public DefaultAugmentedCont1() {
    }


    @Override
    public boolean isLeafValueSet(LeafIdentifier leaf) {
        return valueLeafFlags.get(leaf.getLeafIndex());
    }

}
